function plot_pc_sp(d0,D,s2,basis)
% plot_pc_sp(d0,D,s2,basis)
% Plots (exp of) spatial mean plus/minus pc's for STPP models
%
% Input parameters d0, D, s2, basis are outputs of STPP
%   (in STPP's notation, s2 = s2v and basis = basis_y)
%
% External calls: NGBASIS
%
% Version: April 2019


ng = 50;
t1 = linspace(basis.I1(1),basis.I1(2),ng)';
t2 = linspace(basis.I2(1),basis.I2(2),ng)';
tz = [kron(t1,ones(ng,1)) kron(ones(ng,1),t2)];
tz = tz(basis.Rdom(tz),:);
Bz = NGbasis(tz,basis,0);

p = size(D,2);
if p==0
    figure
    mu = Bz*d0;
    plot3(tz(:,1),tz(:,2),exp(mu),'b.')
    title('Baseline')
    axis tight
else
    for i = 1:p
        figure
        c = 2*sqrt(s2(i));
        mu = Bz*d0;
        pc = Bz*D;
        plot3(tz(:,1),tz(:,2),exp(mu),'b.',...
            tz(:,1),tz(:,2),exp(mu-c*pc(:,i)),'g.',...
            tz(:,1),tz(:,2),exp(mu+c*pc(:,i)),'r.')
        title(['PC ' num2str(i)])
        axis tight
    end
end
